Hedgehog Client Library
=======================

.. image:: https://travis-ci.org/PRIArobotics/HedgehogClient.svg?branch=master
    :target: https://travis-ci.org/PRIArobotics/HedgehogClient

This project provides a client library to communicate with Hedgehog Educational Robotics Controllers.
